__version__ = "1.0.0"
__license__ = "MIT License"
__website__ = "https://github.com/navio-online/navio-builder/"
__download_url__ = "https://github.com/navio-online/navio-builder/archive/" "{}.tar.gz".format(__version__)
